@@ -21,7 +21,6 @@ Validators for Splunk configuration.
 
 import json
 import re
-import sys
 import warnings
 from inspect import isfunction
 
@@ -42,7 +41,6 @@ __all__ = [
     "Email",
     "JsonString",
 ]
-basestring = str if sys.version_info[0] == 3 else basestring
 
 
 class Validator:
@@ -292,17 +290,11 @@ class Number(Validator):
         self._is_int = is_int
 
     def _check(self, val):
-        try:
-            return val is None or isinstance(val, (int, long, float))
-        except NameError:
-            return val is None or isinstance(val, (int, float))
+        return val is None or isinstance(val, (int, float))
 
     def validate(self, value, data):
         try:
-            try:
-                value = long(value) if self._is_int else float(value)
-            except NameError:
-                value = int(value) if self._is_int else float(value)
+            value = int(value) if self._is_int else float(value)
         except ValueError:
             self.put_msg(
                 "Invalid format for %s value"
@@ -312,7 +304,7 @@ class Number(Validator):
 
         msg = None
         if not self._min_val and self._max_val and value > self._max_val:
-            msg = "Value should be smaller than {max_val}".format(max_val=self._max_val)
+            msg = f"Value should be smaller than {self._max_val}"
         elif not self._max_val and self._min_val and value < self._min_val:
             msg = "Value should be no smaller than {min_val}".format(
                 min_val=self._min_val
@@ -358,13 +350,10 @@ class String(Validator):
     def _check(self, val):
         if val is None:
             return True
-        try:
-            return isinstance(val, (int, long)) and val >= 0
-        except NameError:
-            return isinstance(val, (int)) and val >= 0
+        return isinstance(val, int) and val >= 0
 
     def validate(self, value, data):
-        if not isinstance(value, basestring):
+        if not isinstance(value, str):
             self.put_msg("Input value should be string")
             return False
 
@@ -411,7 +400,7 @@ class Datetime(Validator):
         try:
             datetime.datetime.strptime(value, self._format)
         except ValueError as exc:
-            error = 'Wrong datetime with format "{}": {}'.format(self._format, str(exc))
+            error = f'Wrong datetime with format "{self._format}": {str(exc)}'
             self.put_msg(error)
             return False
         return True
